import subprocess
import os
import tempfile


def _qemu_compat_supported():
    # There appears to be no reliable way of knowing if this compat option is available
    # other than trying to use it and capturing the return code/state

    tf = tempfile.NamedTemporaryFile()
    tf.close()
    # Very mild race here as someone else might grab an identically named
    # temp file.  We will live with it.
    try:
        cmd = [ 'qemu-img', 'create', '-f', 'qcow2', '-o', 'compat=0.10', tf.name, '1G' ]
        subprocess.call(cmd)
        os.unlink(tf.name)
        return True
    except subprocess.CalledProcessError:
        return False

def qemu_convert(inputfn, outputfn):
    convert_cmd = [ 'qemu-img', 'convert', '-f', 'qcow2' ]
    if _qemu_compat_supported():
        convert_cmd += [ '-o', 'compat=0.10' ]
    convert_cmd += [ inputfn, outputfn ]

qemu_convert("infile", "outfile")    
qemu_convert("infile", "outfile")    
